@@ -6,13 +6,13 @@ from os.path import expanduser, join
 from picomc.proxy import Proxy
 
 APP_ROOT = {
-    'linux': lambda: expanduser('~/.local/share/picomc'),
-    'win32': lambda: join(os.getenv('APPDATA'), '.picomc'),
-    'darwin': lambda: expanduser('~/Library/Application Support/picomc')
+    "linux": lambda: expanduser("~/.local/share/picomc"),
+    "win32": lambda: join(os.getenv("APPDATA"), ".picomc"),
+    "darwin": lambda: expanduser("~/Library/Application Support/picomc"),
 }[sys.platform]()
 
 try:
-    PLATFORM_MAP = {'darwin': 'osx', 'win32': 'windows', 'linux': 'linux'}
+    PLATFORM_MAP = {"darwin": "osx", "win32": "windows", "linux": "linux"}
     platform = PLATFORM_MAP[sys.platform]
 except KeyError:
     # This is probably not neccesary, as the game is not officialy supported
@@ -21,6 +21,21 @@ except KeyError:
     platform = sys.platform
 
 
+def get_app_root():
+    return APP_ROOT
+
+
+def set_app_root(root):
+    # FIXME. I don't like this global variable solution. Temporary (tm).
+    global APP_ROOT
+    APP_ROOT = os.path.abspath(root)
+
+
+# FIXME. This is not very good design
+class Global:
+    debug = False
+
+
 def get_default_java():
     # FIXME. This is just a placeholder.
     return "java"
